# Docker 配置文件

这个目录包含了Spiderman项目的所有Docker相关配置文件。

## 文件说明

### Dockerfile
多阶段构建的Docker镜像配置文件：
- 基于Alpine Linux，镜像大小仅66.2MB
- 非root用户运行，增强安全性
- 内置健康检查
- 支持环境变量配置

### docker-compose.yml
Docker Compose服务编排配置：
- 服务名：`spiderman-api`
- 端口映射：`8888:8888`
- 环境变量配置
- 健康检查
- 重启策略

### DOCKER_GUIDE.md
详细的Docker使用指南，包含：
- 镜像构建说明
- 容器运行方法
- 环境变量配置
- 故障排除指南

## 快速开始

### 构建镜像
```bash
# 在项目根目录执行
docker build -t spiderman -f docker/Dockerfile .
```

### 运行容器
```bash
# 单独运行
docker run -p 8888:8888 spiderman

# 使用docker-compose
cd docker && docker-compose up -d
```

### 使用Makefile
```bash
# 构建镜像
make docker-build

# 运行容器
make docker-run

# 使用docker-compose
make docker-compose-up
```

## 端口说明

- **8888**: API服务端口（可通过环境变量PORT修改）
- **健康检查**: `GET /health`
- **Swagger文档**: `GET /swagger/index.html`

## 环境变量

主要环境变量配置：
- `PORT`: 服务端口 (默认: 8888)
- `CHAINCODE_NAME`: 链码名称 (默认: basic)
- `CHANNEL_NAME`: 通道名称 (默认: mychannel)
- `LOG_LEVEL`: 日志级别 (默认: info)
- `LOG_FORMAT`: 日志格式 (默认: json)

详细配置请参考 `DOCKER_GUIDE.md`。 